function Out = convertCam2Parameter(cam)
%function converts a camera setup given as cam = [angle, 3d-rotation axis
%translation;...] to a Parametervector Out in R^(6*size(cam,1))
%
%Input:
%   cam: camera setup
%Output:
%   Out: Parameter vector

%check input
if size(cam,2)~=7
    error '[alsc:] Wrong dimension of camera input.'
end

%initialize output
Out = zeros(6*size(cam,1),1);

%calculation
for k=1:size(cam, 1)
    if norm(cam(k,2:4))~=0
        Out(6*(k-1)+1:6*k-3) = cam(k,2:4)./norm(cam(k,2:4))*cam(k,1);
        buf = expm(skewsymetric(Out(6*(k-1)+1:6*k-3)));
    else
        buf = eye(3,3);
    end
    Out(6*(k-1)+4:6*k) = buf*cam(k,5:7)';
end


%=========== auxiliary functions =====================================
function A = skewsymetric(r)
A = [0 -r(3) r(2);r(3) 0 -r(1);-r(2) r(1) 0];