function out = convertRot2Vec(R)
%this function converts a SO(3) matrix to a vector x so that R =
%expm(skew(x))
%Input:
%   R: SO(3) matrix
%Ouput:
%   x: 3d-vector


t = R(1,1)+R(2,2)+R(3,3);
r = sqrt(1+t);
s = 0.5/r;
%calculate quaternion (w x y z)
w = 0.5*r;
x = (R(3,2)-R(2,3))*s;
y = (R(1,3)-R(3,1))*s;
z = (R(2,1)-R(1,2))*s;
%transform to vector
theta = 2*acos(w);
if abs(theta) < 1e-12   %theta close to zero
    out = zeros(3,1);
else
    out = [x/sin(theta/2);y/sin(theta/2);z/sin(theta/2)];
    out = out./norm(out).*theta;
end