function x = generateViewCoordinates(pt, cam)
% Generates the Image Projection of 3D points given a camera matrix, 
% i.e. rotation and translation with respect to world coordinates. 
% Note that itt is assumed the projections are normalized to the camera 
% intrinsic parameters
%
%Input:
%   pt:     row vector containing N 3D coordinate points. It is of
%   dimensions 3Nx1 in the format [X1 Y1 Z1 X2 Y2 Z2...]
%   cam:    (3 x 4) matrix containing [R T]
%
%Output:
%   x:      2D image coordinates of pt. It is of
%   dimensions 2Nx1 in the format [x1 y1 x2 y2...]


%initialize output and intermediate variables
x = zeros(2*length(pt)/3,1);
ex = [1 2];

%calculate output
for k=1:length(pt)/3
    buf = cam*[pt(1+(k-1)*3:k*3);1];                                %padding 1 for homogenuous coordinates
    alpha = buf(3:3:end);                                           %extract weights (z coordinate) to make coordinates homogenuous
    dg = diag(1./reshape(repmat(alpha, 1, 3)',1,[]));               %extract diagonal matrix of weights
    dg1 = dg(ex,:);                                                 %extract rows [1 2]
    x(1+(k-1)*2:k*2) = dg1*buf;
end

