function test_algorithms

% Generate 8 3D points
X = generateCube([1 0 3], 0.5);

% Generate Camera
cam_setup = [pi/2 pi/4 1 0 -3 0 -3];

%Initializations
%s = RandStream('mcg16807');
%RandStream.setDefaultStream(s);

iteration = 30;

%Get Ground Truth
cam_gt = generateCameraRotTrans(cam_setup);
x = generateViewCoordinates(X, cam_gt);

%2D & 3D points
x = x(:);
X = X(:);

%Generate initial Motion Estimate
cam_init = randn(size(cam_setup));
cam_init = generateCameraRotTrans(cam_init);
       
display('Ground Truth Motion [R T]');
display(cam_gt);

display('Initital Motion Estimate [R T]');
display(cam_init);

%test SE3
cam_se3 = newton_manifold_se3(x,X,cam_init,0,iteration);

display('Estimated Motion with SE3 Parameterization [R T]');
display(cam_se3(1:3,:));

%test SO3
cam_so3 = newton_manifold_r3_so3(x,X,cam_init,0,iteration);
display('Estimated Motion with R3xSO3 Parameterization [R T]');
display(cam_so3(1:3,:));





function X = generateCube(cen, len)
%generating eight 3D coordinates of a cube
%
%Input:
%   cen: center of the 8 points of the cube (3-dimensional vector)
%   len: side length of the cube (positive integer value)
%Output:
%   X: row vector containing all 8 points (3*8 = 24 dimensional vector)


%check for valid input
cen = cen(:);
len = abs(len(1));

%initialize output
X = zeros(24, 1);

%calculate points
d = len/2;
for k=0:7
    X(3*k+1:3*k+3) = cen + [(-1)^floor(k/4)*d; (-1)^floor(k/2)*d; (-1)^k*d;];
end